# Numeric (Mathematical)

try:
    from mpmath import *
except:
    pass

# Plotting is included
